@@ -4,10 +4,12 @@ from tkinter import ttk
 from pathlib import Path
 from PIL import Image, ImageTk
 
-import psiutils.text as txt
+from psiutils.text import Text
 
-from .constants import PAD, Pad
-from .widgets import enter_widget, clickable_widget, HAND
+from psiutils.constants import PAD, Pad
+from psiutils.widgets import enter_widget, clickable_widget, HAND
+
+txt = Text()
 
 
 class IconButton(ttk.Frame):
@@ -16,8 +18,8 @@ class IconButton(ttk.Frame):
             master,
             button_text,
             icon,
-            dimmable: bool = False,
             command=None,
+            dimmable: bool = False,
             sticky: str = '',
             icon_path: str = '',
             **kwargs):
@@ -48,7 +50,7 @@ class IconButton(ttk.Frame):
     def __repr__(self) -> str:
         return f'IconButton: {self.text} {self.icon}'
 
-    def state(self) -> dict:
+    def state(self, *args, **kwargs) -> dict:
         return self._state
 
     def enable(self, enable: bool = True) -> None:
@@ -124,8 +126,8 @@ class ButtonFrame(ttk.Frame):
     def icon_button(
             self,
             id_: str,
-            dimmable: bool = False,
-            command: object = None) -> IconButton:
+            command: object = None,
+            dimmable: bool = False,) -> IconButton:
         button = self.icon_buttons[id_]
         button.dimmable = dimmable
         button.command = command
