@@ -1,4 +1,6 @@
 """Constants for the tkinter psiutils."""
+from enum import Enum, auto
+
 from .utilities import invert
 from .known_paths import get_documents_dir, get_downloads_dir
 
@@ -61,5 +63,25 @@ class Pad():
     N = (PAD, 0)
     S = (0, PAD)
 
+
 DOCUMENTS_DIR = get_documents_dir()
 DOWNLOADS_DIR = get_downloads_dir()
+
+
+class Mode(Enum):
+    VIEW = auto()
+    NEW = auto()
+    EDIT = auto()
+    DELETE = auto()
+
+
+class Status(Enum):
+    YES = True
+    NO = False
+    CANCEL = None
+    NULL = 0
+    EXIT = 1
+    OK = 2
+    UPDATED = 3
+    ERROR = 4
+    WARNING = 5
